<?php
class bookDps extends moduleDps {
	private $_assetsLoaded = false;
	private $_bookParamsDesc = array();
	public function init() {
		parent::init();
		add_shortcode('publication_supsystic', array($this, 'displayBook'));
		add_action('wp_footer', array($this, 'addBooksDataToJs'));
		// Add same input fields to add Book form
		add_action(DPS_BOOK. '_add_form_fields', array($this, 'getBookAdminAddFormInput'));
		add_action(DPS_BOOK. '_edit_form_fields', array($this, 'getBookAdminFormInput'), 10, 2);
		add_action(DPS_BOOK. '_edit_form_fields', array($this, 'loadAdminAssets'), 10, 2);
		// Add preview button at the bottom of edit form
		add_action(DPS_BOOK. '_edit_form', array($this, 'getBookAdminEditFormButtons'), 99, 2);
		// Add some book tabs at the bottom of the edit page
		add_action(DPS_BOOK. '_edit_form', array($this, 'getBookAdminEditTabs'), 10, 2);
		// 2 filters - one for save edited tax, other - for add new one form
		add_action('edited_'. DPS_BOOK, array($this, 'saveBookFormInput'), 10, 2);
		add_action('create_'. DPS_BOOK, array($this, 'saveBookFormInput'), 10, 2);
		// Add additional columns for Books
		add_filter('manage_edit-'. DPS_BOOK. '_columns', array($this, 'initBookAdminColumns'));
		add_filter('manage_'. DPS_BOOK. '_custom_column', array($this, 'addBookAdminColumns'), 10, 3);
		// Open our menu for Books menu item
		add_filter('parent_file', array($this, 'checkBooksAdminParentPage'));
		// Add our actions to admin books table - modify preview, "Add Page"
		add_filter(DPS_BOOK. '_row_actions', array($this, 'rebuildAdminTblActions'), 10, 2);
		// Add live preview to edit book form
		//add_action(DPS_BOOK. '_edit_form', array($this, 'getBookLivePreview'), 10, 2);
		// Add to admin bar new item
		add_action('admin_bar_menu', array($this, 'addAdminBarNewItem'), 300);
		add_filter('jetpack_photon_skip_image', array($this, 'checkDpsImgClass'), 10, 3);
	}
	function checkDpsImgClass( $val, $src, $tag ) {
		if($tag && is_string($tag) && strrchr($tag, 'supsystic-dps-img')) {
			$val = true;
		}
		return $val;
	}
	public function displayBook($params, $opts = array()) {
		$params['id'] = isset($params['id']) ? (int) $params['id'] : 0;
		if($params['id']) {
			$this->loadAssets();
			$multi_id = is_multisite() && !empty($params['multi_id']) ? $params['multi_id'] : false;
			if($multi_id) {
				switch_to_blog($params['multi_id']);
			}
			$book = $this->getView()->getBookHtml($params, $opts);
			if($multi_id) {
				restore_current_blog();
			}
			return $book;
		}
		return false;
	}
	public function loadAssets() {
		if(!$this->_assetsLoaded) {
			frameDps::_()->addStyle('book', $this->getModPath(). 'css/book.css');
			frameDps::_()->getModule('templates')->loadCoreJs();
			frameDps::_()->addScript('modernizr', $this->getModPath(). 'js/modernizr.2.5.3.min.js');
			frameDps::_()->addScript('book.class', $this->getModPath(). 'js/book.class.js');
			frameDps::_()->addScript('book.manager.class', $this->getModPath(). 'js/book.manager.class.js');
			frameDps::_()->addScript('book', $this->getModPath(). 'js/book.js', false, false, true);
			frameDps::_()->getModule('templates')->loadFontAwesome();
			//frameDps::_()->addJSVar('book', 'bookModPath', $this->getModPath());
			frameDps::_()->addJSVar('book', 'bookCoreFolderPath', dispatcherDps::applyFilters('bookCorePath', ''));
			$this->_assetsLoaded = true;
		}
	}
	public function loadAdminAssets() {
		frameDps::_()->addScript('admin.book', $this->getModPath(). 'js/admin.book.js');
		frameDps::_()->addJSVar('admin.book', 'dpsDefaultAudioPaging', $this->getDefaultAudioPaging());
		frameDps::_()->addStyle('admin.book', $this->getModPath(). 'css/admin.book.css');
		frameDps::_()->addStyle('bookTb_simple', $this->getModPath(). 'css/bookTb_simple.css');
		frameDps::_()->addStyle('bookTb_night', $this->getModPath(). 'css/bookTb_night.css');
	}
	public function addBooksDataToJs() {
		$books = $this->getView()->getUsedBooks();
		if(!empty($books)) {
			frameDps::_()->addJSVar('book', 'dpsAllBooks', $books);
		}
	}
	public function getBookAdminFormInput($tag) {
		$this->addLivePreviewAssets();
		frameDps::_()->addScript('admin.book.edit', $this->getModPath(). 'js/admin.book.edit.js', false, true);
		$this->getView()->getBookAdminFormInput($tag);
	}
	public function getBookAdminAddFormInput($tag) {
		$this->getView()->getBookAdminFormInput($tag, array('addForm' => true));
	}
	public function getBookParamsDesc() {
		if(!$this->_bookParamsDesc) {
			$this->_bookParamsDesc = dispatcherDps::applyFilters('bookParamsDesc', array(
				//Width and height parameters of publication area and pages
				'area_width_units' => array(
					'label' => __('Area Width', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'px' => __('Px', DPS_LANG_CODE),
							'%' => __('Percents', DPS_LANG_CODE)),
						'value' => '%',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Defines the width of the publication background area in pixels or percents (%).', DPS_LANG_CODE),
					'show_on_create' => true),
				'area_width' => array(
					'label' => __('Area Width', DPS_LANG_CODE),
					'type' => 'text',
					'default' => frameDps::_()->getModule('options')->get('def_area_width'),
					'show_on_create' => true),
				'area_height' => array(
					'label' => __('Area Height', DPS_LANG_CODE),
					'type' => 'text',
					'default' => frameDps::_()->getModule('options')->get('def_area_height'),
					'desc' => __('Defines the height of the publication background area in pixels.', DPS_LANG_CODE),
					'show_on_create' => true),
				'width' => array(
					'label' => __('Publication Width', DPS_LANG_CODE),
					'type' => 'text',
					'default' => frameDps::_()->getModule('options')->get('def_width'),
					'desc' => __('Defines the publication width in pixels.', DPS_LANG_CODE),
					'show_on_create' => true),
				'height' => array(
					'label' => __('Publication Height', DPS_LANG_CODE),
					'type' => 'text',
					'default' => frameDps::_()->getModule('options')->get('def_height'),
					'desc' => __('Defines the publication height in pixels.', DPS_LANG_CODE),
					'show_on_create' => true),

				//Publication area background parameters
				'bg_type' => array(
					'label' => __('Area Background Type', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'none' => __('None', DPS_LANG_CODE),
							'color' => __('Color', DPS_LANG_CODE),
							'img' => __('Image', DPS_LANG_CODE)),
						'value' => 'none',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Background type for area of publication window.', DPS_LANG_CODE),),
				'bg_color' => array(
					'label' => __('- Area Color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#e5e5e5',
					'desc' => __('Choose the background color.', DPS_LANG_CODE),),
				'bg_opacity' => array(
					'label' => __('- Area Opacity', DPS_LANG_CODE),
					'type' => 'slider',
					'default' => 1,
					'params' => array(
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
						'slide' => 'dpsOnAdminOpacitySlideMove'),
					'desc' => __('Sets area background opacity.', DPS_LANG_CODE),),
				'bg_img' => array(
					'label' => __('- Area Image', DPS_LANG_CODE),
					'type' => 'imgGalleryBtn',
					'params' => array(
						'onChange' => 'dpsOnAdminBgImgChange',
						'attrs' => 'class="button"'),
					'desc' => __('Choose the background image.', DPS_LANG_CODE),),
				'bg_img_pos' => array(
					'label' => __('- Area Image Position', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'center' => __('Center', DPS_LANG_CODE),
							'tile' => __('Tile', DPS_LANG_CODE),
							'stretch' => __('Stretch', DPS_LANG_CODE)),
						'value' => 'center',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Choose the background image position.', DPS_LANG_CODE),),

				//Publication pages background parameters
				'page_bg_type' => array(
					'label' => __('Pages Background Type', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'none' => __('None', DPS_LANG_CODE),
							'color' => __('Color', DPS_LANG_CODE),
							'img' => __('Image', DPS_LANG_CODE)),
						'value' => 'none',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Background type for pages of publication.', DPS_LANG_CODE),),
				'page_bg_color' => array(
					'label' => __('- Pages Color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#ffffff',
					'desc' => __('Choose the background color.', DPS_LANG_CODE),),
				'page_bg_opacity' => array(
					'label' => __('- Pages Opacity', DPS_LANG_CODE),
					'type' => 'slider',
					'default' => 1,
					'params' => array(
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
						'slide' => 'dpsOnAdminOpacitySlideMove'),
					'desc' => __('Sets pages background opacity.', DPS_LANG_CODE),),
				'page_bg_img' => array(
					'label' => __('- Pages Image', DPS_LANG_CODE),
					'type' => 'imgGalleryBtn',
					'params' => array(
						'onChange' => 'dpsOnAdminPageBgImgChange',
						'attrs' => 'class="button"'),
					'desc' => __('Choose the background image.', DPS_LANG_CODE),),
				'page_bg_img_pos' => array(
					'label' => __('- Pages Image Position', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'center' => __('Center', DPS_LANG_CODE),
							'tile' => __('Tile', DPS_LANG_CODE),
							'stretch' => __('Stretch', DPS_LANG_CODE)),
						'value' => 'center',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Choose the background image position.', DPS_LANG_CODE),),

				//Common publication properties
				'cover_type' => array(
					'label' => __('Cover Type', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'softcover' => __('Soft', DPS_LANG_CODE),
							'hardcover' => __('Hard', DPS_LANG_CODE)),
						'value' => 'softcover',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Type of the publication\'s cover.', DPS_LANG_CODE),),
				'en_audio_paging' => array(
					'label' => __('Enable Audio Paging', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true),),
				'audio_paging' => array(
					'label' => __('Flip Sound', DPS_LANG_CODE),
					'type' => 'audioGalleryBtn',
					'params' => array(
						'onChange' => 'dpsOnAdminAudioChange',
						'attrs' => 'class="button" style="vertical-align: middle;"'),
					'default' => $this->getDefaultAudioPaging(),
					'desc' => __('Select audio file for sound of page flipping. Note: This feature is supported only in HTML5 browsers. Internet Explorer does not support .wav format.', DPS_LANG_CODE),),
				'transition_direction' => array(
					'label' => __('Transition Direction', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'ltr' => __('Left to Right', DPS_LANG_CODE),
							'rtl' => __('Right to Left', DPS_LANG_CODE)),
						'value' => 'ltr',
						'labeled' => true,
						'no_br' => true),
					'desc' => __('Direction of publication pages transition.', DPS_LANG_CODE),),
				'transition_duration' => array(
					'label' => __('Transition Duration', DPS_LANG_CODE),
					'type' => 'text',
					'default' => '600',
					'desc' => __('Sets the transition duration for page turning in milliseconds. If you set 0 (zero) - there will be no transition.', DPS_LANG_CODE),),
				'open_on_page' => array(
					'label' => __('Open Publication On Page', DPS_LANG_CODE),
					'type' => 'text',
					'default' => '1',
					'desc' => __('Publication will be opened on the provided page number, if empty or zero - it will be the first page. Important! If Open Fullscreen On Click option is enabled -  publication in any case will be opened on the first page, regardless of the current option value. However, if publication have an even number of pages - you can set the last page as the page to open the publication.', DPS_LANG_CODE),),
				'page_content_indent' => array(
					'label' => __('Content Indent', DPS_LANG_CODE),
					'type' => 'text',
					'default' => '',
					'desc' => __('Indent from edge of the page to it\'s internal content in px.', DPS_LANG_CODE),),
				'indent_text_only' => array(
					'label' => __('- Text Pages Only', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '',
						'labeled' => true,
						'no_br' => true),
					'desc' => __('If enabled - the content indent will be applied only for publication pages, which contain some text', DPS_LANG_CODE),),
				'zoom_level' => array(
					'label' => __('Zoom Level', DPS_LANG_CODE),
					'type' => 'text',
					'default' => '2',
					'desc' => __('Zoom level, that will be set after you click on Zoom button', DPS_LANG_CODE),),
				'en_page_shadow' => array(
					'label' => __('Border Shadow', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Shows border shadow on publication perimeter.', DPS_LANG_CODE),),
				'en_fake_pages' => array(
					'label' => __('Volume Fake Pages', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Adds effect of volume pages, like in real publication.', DPS_LANG_CODE),),
				'en_gradients' => array(
					'label' => __('Show Gradients', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Shows gradients and shadows during the transition.', DPS_LANG_CODE),),
				'en_fullscreen_onclick' => array(
					'label' => __('Open Fullscreen On Click', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Enable fullscreen mode by click on publication pages.', DPS_LANG_CODE),),
				'dis_fullscreen_onclick' => array(
					'label' => __('Close Fullscreen On Click', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Disable fullscreen mode by click outside of publication pages.', DPS_LANG_CODE),),
				/*'en_pages_dynamic_preload' => array(	// This parameter can be required if we will decide to draw all pages - right after load. For now - it is only 6 pages will be rendered.
					'label' => __('Load Pages One-by-One', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Content of all pages will not be loaded during publication load - it will be pre-loaded when page will be needed to show.', DPS_LANG_CODE),),*/

				/*'social_links' => array(
					'label' => __('Social links', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Social links for your publication', DPS_LANG_CODE),),*/

				//Publication custom pages
				'import_post' => array(
					'label' => __('Posts', DPS_LANG_CODE),
					'type' => 'selectlist',
					'tab' => 'pages_import',
					'ignore' => true,
					'remove' => true,
					'params' => array(
						'options' => array(),
						'value' => '',
						'attrs' => 'class="chosen_auto_width"'),
					'desc' => '',),
				'import_page' => array(
					'label' => __('Pages', DPS_LANG_CODE),
					'type' => 'selectlist',
					'tab' => 'pages_import',
					'ignore' => true,
					'remove' => true,
					'params' => array(
						'options' => array(),
						'value' => '',
						'attrs' => 'class="chosen_auto_width"'),
					'desc' => '',),
				'import_product' => array(
					'label' => __('Woocommerce Products', DPS_LANG_CODE),
					'type' => 'selectlist',
					'tab' => 'pages_import',
					'promo' => true,
					'ignore' => true,
					'remove' => true,
					'params' => array(
						'options' => array(),
						'value' => '',
						'disabled' => true,
						'attrs' => 'class="chosen_auto_width"'),
					'desc' => '',),
				//Publication toolbar parameters: design
				'toolbar_code' => array(
					'label' => __('Toolbar Design', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'simple' => __('Simple', DPS_LANG_CODE)),
						'value' => 'simple',
						'labeled' => true,
						'no_br' => true,
						'hidden' => true),
					'desc' => __('Choose design of publication window toolbar.', DPS_LANG_CODE),),
				'toolbar_preset' => array(
					'label' => __('Toolbar Preset', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'colorset' => __('Colorset', DPS_LANG_CODE),
							'borderset' => __('Borderset', DPS_LANG_CODE)),
						'value' => 'colorset',
						'labeled' => true,
						'no_br' => true,),),
				'toolbar_bg_color' => array(
					'label' => __('Background Color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#404040',
					'desc' => __('Select toolbar background color.', DPS_LANG_CODE),),
				'toolbar_bg_opacity' => array(
					'label' => __('Background Opacity', DPS_LANG_CODE),
					'type' => 'slider',
					'default' => 1,
					'params' => array(
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
						'slide' => 'dpsOnAdminOpacitySlideMove'),
					'desc' => __('Sets toolbar background opacity.', DPS_LANG_CODE),),
				'toolbar_btns_color' => array(
					'label' => __('Buttons Color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#ADADAD',
					'desc' => __('Select custom button color.', DPS_LANG_CODE),),
				'toolbar_btns_active_color' => array(
					'label' => __('Buttons Active Color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#D6D6D6',
					'desc' => __('Select custom active button color.', DPS_LANG_CODE),),
				'en_toolbar_shadow' => array(
					'label' => __('Toolbar Shadow', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Show/hide toolbar shadow.', DPS_LANG_CODE),),

				//Publication toolbar parameters: tooltips
				/*'en_toolbar_tootips' => array(
					'label' => __('Toolbar Tooltips', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Show/hide toolbar tooltips.', DPS_LANG_CODE),),
				'toolbar_tootips_bg_color' => array(
					'label' => __('- Background color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#ffffff',
					'desc' => __('Select tooltips background color.', DPS_LANG_CODE),),
				'toolbar_tootips_txt_color' => array(
					'label' => __('- Text Color', DPS_LANG_CODE),
					'type' => 'colorpicker',
					'default' => '#ffffff',
					'desc' => __('Select tooltips text color.', DPS_LANG_CODE),),
				'toolbar_tootips_txt_font' => array(
					'label' => __('- Text Font', DPS_LANG_CODE),
					'type' => 'text',
					'desc' => __('Select tooltips text font family.', DPS_LANG_CODE),),
				'toolbar_tootips_txt_size' => array(
					'label' => __('- Text Size', DPS_LANG_CODE),
					'type' => 'text',
					'desc' => __('Select tooltips text size.', DPS_LANG_CODE),),*/

				//Publication toolbar parameters: buttons displaying
				'en_fw_bw_btns' => array(
					'label' => __('Forward / Backward Buttons', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Buttons for turning publication pages.', DPS_LANG_CODE),),
				'en_page_nmb_field' => array(
					'label' => __('Page Numbers Field', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Field with number of publication pages.', DPS_LANG_CODE),),
				'en_print_export_btn' => array(
					'label' => __('Print / Export Button', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Button for publication export into the PDF file or onto the HTML page for printing.', DPS_LANG_CODE),),
				'en_search_btn' => array(
					'label' => __('Search Button', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Button for text searching in the publication.', DPS_LANG_CODE),),
				'en_fullscreen_btn' => array(
					'label' => __('Fullscreen Button', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Button for displaying publication in the fullscreen mode.', DPS_LANG_CODE),),
				'en_zoom_btn' => array(
					'label' => __('Zoom Button', DPS_LANG_CODE),
					'type' => 'radiobuttons',
					'params' => array(
						'options' => array(
							'1' => __('Enable', DPS_LANG_CODE),
							'' => __('Disable', DPS_LANG_CODE)),
						'value' => '1',
						'labeled' => true,
						'no_br' => true,),
					'desc' => __('Button for publication zooming.', DPS_LANG_CODE),),
			));
		}
		return $this->_bookParamsDesc;
	}
	public function saveBookFormInput($termId) {
		$data = reqDps::getVar('dps');
		if(empty($data)) {
			// This is used for example to update book options when add batch pages, @see bookControllerDps::addPagesFromImages()
			$bookParams = reqDps::getVar('bookParams');
			if(!empty($bookParams) && isset($bookParams['dps']) && !empty($bookParams['dps'])) {
				$data = $bookParams['dps'];
			}
		}
		if(!empty($data)) {
			$data['id'] = $termId;
			$this->getModel()->saveBookParams($data);
		}
	}
	public function initBookAdminColumns($cols) {
		$keys = array('cb', 'id', 'name', 'pages_list', 'shortcode', 'params');
		$sortedCols = array();

		unset($cols['description']);
		unset($cols['slug']);
		unset($cols['posts']);

		$cols['id'] = __('ID', DPS_LANG_CODE);
		$cols['shortcode'] = __('Shortcode', DPS_LANG_CODE);
		$cols['params'] = __('Params', DPS_LANG_CODE);
		$cols['pages_list'] = __('Pages', DPS_LANG_CODE);
		
		foreach($keys as $key) {
			$sortedCols[ $key ] = !empty($cols[ $key ]) ? $cols[ $key ] : '';
		}
		return $sortedCols;
	}
	public function addBookAdminColumns($out, $columnName, $termId) {
		switch ($columnName) {
			case 'id':
				$out = $termId;
				break;
			case 'pages_list':
				$book = $this->getModel()->getById($termId, false, true);
				if($book->count) {
					$out = '<a title="'. __('View publication pages list').'" href="'. admin_url('edit.php?post_type='. DPS_PAGE. '&'. DPS_BOOK. '='. $book->slug). '" target="_blank">'. $book->count. '</a>';
					$out .= '<br />';
					//$out .= '<a title="'. __('Edit publication pages'). '" href="'. $this->getLinkBookEdit($termId, array('hash' => 'dpsAdminBookPages')). '">'. __('Edit', DPS_LANG_CODE). '</a>';
				} else {
					$out = '<a href="'. $this->getLinkAddPageForBook($termId). '">'. __('Start add Pages', DPS_LANG_CODE). '</a>';
				}
				break;
			case 'shortcode':
				$out = $this->generateShortcodeHtml($termId);
				break;
			case 'params':
				$paramsDesc = $this->getBookParamsDesc();
				$params = $this->getModel()->getBookParams($termId);
				$out = $this->_paramsToTable($paramsDesc, $params);
				break;
		}
		return $out;
	}
	public  function generateShortcode($bookId) {
		return '[publication_supsystic id="'. $bookId. '"]';
	}
	public  function generatePhpCode($bookId) {
		return '&lt;?php echo do_shortcode(&#39;[publication_supsystic id="'. $bookId. '"]&#39;) ?&gt;';
	}
	public function generateShortcodeHtml($bookId) {
		return '<div class="gmpShortCodePreview"><span>'. $this->generateShortcode($bookId). '</span></div>';
	}
	public function generatePhpCodeHtml($bookId) {
		return '<div class="gmpPhpCodePreview"><span>'. $this->generatePhpCode($bookId). '</span></div>';
	}
	/**
	 * Just unused for now - until I will image how it will correct and pretty display
	 */
	private function _paramsToTable($paramsDesc, $params) {
		$showOnlyKeys = array('area_width', 'area_height', 'width', 'height');
		$res = '';
		$res .= '<table class="dpsAdminBookParamsShowListTbl">';
		foreach($showOnlyKeys as $key) {
			if($key == 'area_width') {
				$units = $params['area_width_units'];
			} else {
				$units = 'px';
			}
			$res .= '<tr><td>'. $paramsDesc[ $key ]['label']. '</td><td>'. (isset($params[$key]) ? $params[$key]. $units : ''). '</td></tr>';
		}
		$res .= '</table>';
		return $res;
	}
	public function checkBooksAdminParentPage($parent_file) {
		if(frameDps::_()->getModule('pages')->isAdminBooksPage()) {
			$parent_file = frameDps::_()->getModule('adminmenu')->getMainSlug();
		}
		return $parent_file;
	}
	public function rebuildAdminTblActions($actions, $tag) {
		$actions['view'] = '<a target="_blank" href="'. $this->getLinkPreviewBook(array('id' => $tag->term_id)) .'">'. __('Preview', DPS_LANG_CODE). '</a>';
		$actions['add_page'] = '<a href="'. $this->getLinkAddPageForBook($tag->term_id). '">'. __('Add Page', DPS_LANG_CODE). '</a>';
		return $actions;
	}
	public function getLinkAddPageForBook($termId) {
		return admin_url('post-new.php?post_type='. DPS_PAGE. '&'. DPS_BOOK. '='. $termId);
	}
	public function getLinkPreviewBook($params) {
		$url = uriDps::mod('book', 'preview', array('id' => $params['id']));
		if(isset($params['page']) && $params['page']) {
			$url .= '#page'. $params['page'];
		}
		return $url;
	}
	public function getLinkPageEdit($pageId) {
		return admin_url('post.php?post='. $pageId. '&action=edit');
	}
	public function getLinkBookEdit($bookId, $params = array()) {
		$url = admin_url($this->getBookEditLinkBasename() . '?action=edit&taxonomy='. DPS_BOOK. '&tag_ID='. $bookId. '&post_type=post');
		if(isset($params['hash']) && $params['hash']) {
			$url .= '#'. $params['hash'];
		}
		return $url;
	}
	public function getBookEditLinkBasename() {
		if(version_compare(get_bloginfo('version'), '4.5', '<')) {
			return 'edit-tags.php';
		} else {
			return 'term.php';
		}
	}
	public function getLinkBookAdd() {
		return admin_url('edit-tags.php?taxonomy='. DPS_BOOK);
	}
	public function addLivePreviewAssets() {
		frameDps::_()->addScript('admin.book.livepreview', $this->getModPath(). 'js/admin.book.livepreview.js');
	}
	public function getBookAdminEditFormButtons($tag, $taxonomy) {
		if($taxonomy == DPS_BOOK) {	// Additional check
			$this->getView()->displayEditBookFormButtons($tag);
		}
	}
	public function getBookAdminEditTabs($tag, $taxonomy) {
		if($taxonomy == DPS_BOOK) {	// Additional check
			dispatcherDps::doAction('beforeAdminBookRender');
			frameDps::_()->addScript('wp.tabs', DPS_JS_PATH. 'wp.tabs.js');
			frameDps::_()->addScript('jquery-ui-sortable');
			$this->getView()->displayEditBookFormTabs($tag);
		}
	}
	public function getDefaultAudioPaging() {
		static $url = '';
		if(empty($url)) {
			$url = $this->getModPath(). 'files/page-turn.wav';
		}
		return $url;
	}
	public function canUsePdfExport() {
		return version_compare(phpversion(), '5.3', '>=');
	}
	public function addAdminBarNewItem( $wp_admin_bar ) {
		$mainCap = frameDps::_()->getModule('adminmenu')->getMainCap();
		if(!current_user_can( $mainCap) || !$wp_admin_bar || !is_object($wp_admin_bar)) {
			return;
		}
		$wp_admin_bar->add_menu(array(
			'parent'    => 'new-content',
			'id'        => DPS_CODE. '-admin-bar-new-item',
			'title'     => __('Digital Publication', DPS_LANG_CODE),
			'href'      => $this->getLinkBookAdd(),
		));
	}
}
