<?php
class templatesDps extends moduleDps {
    protected $_styles = array();
	private $_cdnUrl = '';

	public function __construct($d) {
		parent::__construct($d);
		$this->getCdnUrl();	// Init CDN URL
	}
	public function getCdnUrl() {
		if(empty($this->_cdnUrl)) {
			if((int) frameDps::_()->getModule('options')->get('use_local_cdn')) {
				$uploadsDir = wp_upload_dir( null, false );
				$this->_cdnUrl = $uploadsDir['baseurl']. '/'. DPS_CODE. '/';
				if(uriDps::isHttps()) {
					$this->_cdnUrl = str_replace('http://', 'https://', $this->_cdnUrl);
				}
				dispatcherDps::addFilter('externalCdnUrl', array($this, 'modifyExternalToLocalCdn'));
			} else {
				$this->_cdnUrl = (uriDps::isHttps() ? 'https' : 'http'). '://supsystic-42d7.kxcdn.com/';
			}
		}
		return $this->_cdnUrl;
	}
	public function init() {
		if (is_admin()) {
			$isAdminPlugOptsPage = frameDps::_()->isAdminPlugOptsPage();
			//$isPluginsPage = utilsDps::isPluginsPage();
			$isBooksPage = frameDps::_()->getModule('pages')->isAdminBooksPage();
			$isPagePage = frameDps::_()->getModule('pages')->isAdminPagesPage();

			if($isAdminPlugOptsPage || /*$isPluginsPage ||*/ $isBooksPage || $isPagePage) {
				$this->loadCoreJs();
				$this->loadAdminCoreJs();
				$this->loadCoreCss();
				$this->loadChosenSelects();
				$this->loadFontAwesome();
				frameDps::_()->addScript('adminOptionsDps', DPS_JS_PATH. 'admin.options.js');
				add_action('admin_enqueue_scripts', array($this, 'loadMediaScripts'));
				if($isBooksPage) {
					frameDps::_()->getModule('book')->loadAdminAssets();
				}
				if($isPagePage) {
					frameDps::_()->getModule('page')->loadAdminAssets();
				}
			}
			// Some common styles - that need to be on all admin pages - be careful with them
			frameDps::_()->addStyle('supsystic-for-all-admin'. DPS_CODE, DPS_CSS_PATH. 'supsystic-for-all-admin.css');
		}
		parent::init();
	}
	public function loadMediaScripts() {
		wp_enqueue_media();
	}
	public function loadAdminCoreJs() {
		frameDps::_()->addScript('jquery-ui-dialog');
		frameDps::_()->addScript('jquery-ui-slider');
		frameDps::_()->addScript('wp-color-picker');
		frameDps::_()->addScript('icheck', DPS_JS_PATH. 'icheck.min.js');
		$this->loadTooltipster();
	}
	public function loadCoreJs() {
		frameDps::_()->addScript('jquery-ui-dialog');
		frameDps::_()->addScript('jquery');
		frameDps::_()->addScript('commonDps', DPS_JS_PATH. 'common.js');
		frameDps::_()->addScript('coreDps', DPS_JS_PATH. 'core.js');

		$ajaxurl = admin_url('admin-ajax.php');
		$jsData = array(
			'siteUrl'					=> DPS_SITE_URL,
			'DPS_CODE'					=> DPS_CODE,
			'imgPath'					=> DPS_IMG_PATH,
			'jsPath'					=> DPS_JS_PATH,
			'cssPath'					=> DPS_CSS_PATH,
			'loader'					=> DPS_LOADER_IMG,
			'ajaxurl'					=> $ajaxurl,
			'animationSpeed'			=> frameDps::_()->getModule('options')->get('js_animation_speed'),
			'DPS_BOOK'					=> DPS_BOOK,
			'DPS_PAGE'					=> DPS_PAGE,
			'bookEditUrlPattern'		=> frameDps::_()->getModule('book')->getLinkBookEdit('DYNAMIC_BOOK_ID')
		);
		if(is_admin()) {
			$jsData['isPro'] = frameDps::_()->getModule('supsystic_promo')->isPro();
		}
		$jsData = dispatcherDps::applyFilters('jsInitVariables', $jsData);
		frameDps::_()->addJSVar('coreDps', 'DPS_DATA', $jsData);
	}
	public function loadCoreCss() {
		$this->_styles = array(
			'styleDps'			=> array('path' => DPS_CSS_PATH. 'style.css', 'for' => 'admin'),
			'adminStylesDps'	=> array('path' => DPS_CSS_PATH. 'adminStyles.css', 'for' => 'admin'),
			'supsystic-uiDps'	=> array('path' => DPS_CSS_PATH. 'supsystic-ui.css', 'for' => 'admin'),
			'icheck'			=> array('path' => DPS_CSS_PATH. 'jquery.icheck.css', 'for' => 'admin'),
			'dashicons'			=> array('for' => 'admin'),
			'wp-color-picker'	=> array('for' => 'admin'),
		);
		foreach($this->_styles as $s => $sInfo) {
			if(!empty($sInfo['path'])) {
				frameDps::_()->addStyle($s, $sInfo['path']);
			} else {
				frameDps::_()->addStyle($s);
			}
		}
	}
	public function loadFontAwesome() {
		frameDps::_()->addStyle('font-awesomeDps', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css');
	}
	public function loadChosenSelects() {
		// frameDps::_()->addStyle('jquery.chosen', $this->_cdnUrl. 'lib/chosen/chosen.min.css');
		// frameDps::_()->addScript('jquery.chosen', $this->_cdnUrl. 'lib/chosen/chosen.jquery.min.js');
		frameDps::_()->addStyle('jquery.chosen', DPS_CSS_PATH. 'chosen.min.css');
		frameDps::_()->addScript('jquery.chosen', DPS_JS_PATH. 'chosen.jquery.min.js');
	}
	public function loadTooltipster() {
		// frameDps::_()->addScript('tooltipster', $this->_cdnUrl. 'lib/tooltipster/jquery.tooltipster.min.js');
		// frameDps::_()->addStyle('tooltipster', $this->_cdnUrl. 'lib/tooltipster/tooltipster.css');
		frameDps::_()->addScript('tooltipster', DPS_JS_PATH. 'jquery.tooltipster.min.js');
		frameDps::_()->addStyle('tooltipster', DPS_CSS_PATH. 'tooltipster.css');
	}
	public function loadSlimscroll() {
		// not in use
		frameDps::_()->addScript('jquery.slimscroll', $this->_cdnUrl. 'js/jquery.slimscroll.js');
	}
	public function loadJqueryUi() {
		static $loaded = false;
		if(!$loaded) {
			frameDps::_()->addStyle('jquery-ui', DPS_CSS_PATH. 'jquery-ui.min.css');
			frameDps::_()->addStyle('jquery-ui.structure', DPS_CSS_PATH. 'jquery-ui.structure.min.css');
			frameDps::_()->addStyle('jquery-ui.theme', DPS_CSS_PATH. 'jquery-ui.theme.min.css');
			frameDps::_()->addStyle('jquery-slider', DPS_CSS_PATH. 'jquery-slider.css');
			$loaded = true;
		}
	}
	public function loadBootstrapSimple() {
		static $loaded = false;
		if(!$loaded) {
			frameDps::_()->addStyle('bootstrap-simple', DPS_CSS_PATH. 'bootstrap-simple.css');
			$loaded = true;
		}
	}
	public function loadGoogleFont( $font ) {
		static $loaded = array();
		if(!isset($loaded[ $font ])) {
			frameDps::_()->addStyle('google.font.'. str_replace(array(' '), '-', $font), 'https://fonts.googleapis.com/css?family='. urlencode($font));
			$loaded[ $font ] = 1;
		}
	}
}
